import pytest

import cmyt  # noqa: F401
from cmyt._utils import create_cmap_overview

mpl_compare = pytest.mark.mpl_image_compare(
    savefig_kwargs={"bbox_inches": "tight"},
    style="default",
)


@mpl_compare
@pytest.mark.parametrize("subset", [None, ["pastel", "arbre", "algae"], ["pastel"]])
def test_overview_to_fig(subset):
    return create_cmap_overview(subset=subset, with_grayscale=True)


def test_save_overview_to_file(tmp_path):
    output = tmp_path / "tmp.png"
    create_cmap_overview(filename=output)
    assert output.is_file()



from importlib import import_module

from cmyt._utils import cmyt_cmaps, register_colormap

for name in cmyt_cmaps:
    # register to MPL
    mod = import_module(f"cmyt.colormaps.{name}")
    if hasattr(mod, "data"):
        cmap, cmap_r = register_colormap(name, color_dict=mod.data)
    elif hasattr(mod, "luts"):
        cmap, cmap_r = register_colormap(name, colors=mod.luts)
    else:
        raise RuntimeError(
            f"colormap module '{name}' doesn't contain necessary data for registration."
        )

    globals()[cmap.name] = cmap
    globals()[cmap_r.name] = cmap_r


__all__ = tuple(cmyt_cmaps) + tuple(f"{name}_r" for name in cmyt_cmaps)
